.. _test:

Test
====

Random test images

.. figure:: ../../_images/testlavue.png

The **Test** image source frame contains the following fields:

*    **Status:** shows the connection status. It also displays a port of ZMQ security stream if it is enabled.
*    **Start/Stop** button to launch or interrupt image querying

.. |br| raw:: html

     <br>
